@@ -337,30 +337,21 @@ class cgsi_utils
     //
     // find the source image ... the actual filename
     //
-    $havesrcfile = FALSE;
     $opp['src'] = urldecode($opp['src']);
-//     if( !$outp['error'] && file_exists($opp['src']) ) {
-//       // user specified the complete path to the file.
-//       $srcfile = $opp['src'];
-//       if( startswith($opp['src'],'/') ) $rel = 1;
-//     }    
     if( !$outp['error'] && !$srcfile && startswith($opp['src'],$config['uploads_url']) ) {
       $tmp = str_replace($config['uploads_url'],$config['uploads_path'],$opp['src']);
-      $havesrcfile = TRUE;
       if( file_exists($tmp) ) {
 	$srcfile = $tmp;
       }
     }
     if( !$outp['error'] && !$srcfile && startswith($opp['src'],$config['root_url']) ) {
       $tmp = str_replace($config['root_url'],$config['root_path'],$opp['src']);
-      $havesrcfile = TRUE;
       if( file_exists($tmp) ) {
 	$srcfile = $tmp;
       }
     }
     if( !$outp['error'] && !$srcfile && startswith($opp['src'],'/') ) {
       $tmp = cms_join_path($config['root_path'],$opp['src']);
-      $havesrcfile = TRUE;
       $rp1 = realpath($config['root_path']);
       $rp2 = realpath($tmp);
       if( startswith($rp2,$rp1) && file_exists($tmp) ) {
@@ -369,7 +360,6 @@ class cgsi_utils
     }
     if( !$outp['error'] && !$srcfile ) {
       $tmp = cms_join_path($config['uploads_path'],$opp['src']);
-      $havesrcfile = TRUE;
       $rp1 = realpath($config['root_path']);
       $rp2 = realpath($tmp);
       if( startswith($rp2,$rp1) && file_exists($tmp) ) {
@@ -378,12 +368,11 @@ class cgsi_utils
     }
     if( !$outp['error'] && !$srcfile && isset($config['ssl_url']) && startswith($opp['src'],$config['ssl_url']) ) {
       $tmp = str_replace($config['ssl_url'],$config['root_path'],$opp['src']);
-      $havesrcfile = TRUE;
       if( file_exists($tmp) ) {
 	$srcfile = $tmp;
       }
     }
-    if( !$outp['error'] && !$srcfile && !$havesrcfile && $opp['noremote'] == 0 && 
+    if( !$outp['error'] && !$srcfile && $opp['noremote'] == 0 && 
 	(startswith($opp['src'],'http:') || startswith($opp['src'],'https:') || startswith($opp['src'],'ftp:'))) {
       // okay, gotta assume that ths is a remote file
       // get it, and cache it.
