@@ -40,9 +40,10 @@ $config = cmsms()->GetConfig();
 $this->SetPreference('embed_mode','smart');
 $this->SetPreference('embed_size',32);
 $this->SetPreference('embed_type','png,jpg,gif');
-$this->SetPreference('image_url_prefix',$config['uploads_url']);
+$this->SetPreference('image_url_prefix',$config['root_url']);
 $this->SetPreference('image_url_hascachedir',0);
 $this->SetPreference('cache_age',0);
+$this->SetPreference('cache_path', cms_join_path('uploads', '_'.$this->GetName()));
 
 $aliases = array();
 $aliases[] = array('name'=>'std_thumbnail','options'=>'filter_watermark=1 width=150 height=150');
